pub struct PriorityDomain {
pub type: i32,
pub domain: String,
}Fields
type: i32domain: StringImplementations
Sourceimpl PriorityDomain
impl PriorityDomain
Sourcepub fn type(&self) -> DomainMatchingType
pub fn type(&self) -> DomainMatchingType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: DomainMatchingType)
pub fn set_type(&mut self, value: DomainMatchingType)
Sets type to the provided enum value.