pub struct Config {
pub error_log_type: i32,
pub error_log_level: i32,
pub error_log_path: String,
pub access_log_type: i32,
pub access_log_path: String,
pub enable_dns_log: bool,
}Fields
error_log_type: i32error_log_level: i32error_log_path: Stringaccess_log_type: i32access_log_path: Stringenable_dns_log: boolImplementations
Sourceimpl Config
impl Config
Sourcepub fn error_log_type(&self) -> LogType
pub fn error_log_type(&self) -> LogType
Returns the enum value of error_log_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error_log_type(&mut self, value: LogType)
pub fn set_error_log_type(&mut self, value: LogType)
Sets error_log_type to the provided enum value.
Sourcepub fn error_log_level(&self) -> Severity
pub fn error_log_level(&self) -> Severity
Returns the enum value of error_log_level, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error_log_level(&mut self, value: Severity)
pub fn set_error_log_level(&mut self, value: Severity)
Sets error_log_level to the provided enum value.
Sourcepub fn access_log_type(&self) -> LogType
pub fn access_log_type(&self) -> LogType
Returns the enum value of access_log_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_access_log_type(&mut self, value: LogType)
pub fn set_access_log_type(&mut self, value: LogType)
Sets access_log_type to the provided enum value.