pub struct ReceiverConfig {
pub port_list: Option<PortList>,
pub listen: Option<IpOrDomain>,
pub allocation_strategy: Option<AllocationStrategy>,
pub stream_settings: Option<StreamConfig>,
pub receive_original_destination: bool,
pub domain_override: Vec<i32>,
pub sniffing_settings: Option<SniffingConfig>,
}Fields
port_list: Option<PortList>PortList specifies the ports which the Receiver should listen on.
listen: Option<IpOrDomain>Listen specifies the IP address that the Receiver should listen on.
allocation_strategy: Option<AllocationStrategy>stream_settings: Option<StreamConfig>receive_original_destination: booldomain_override: Vec<i32>👎Deprecated
Override domains for the given protocol. Deprecated. Use sniffing_settings.
sniffing_settings: Option<SniffingConfig>Implementations
Sourceimpl ReceiverConfig
impl ReceiverConfig
Sourcepub fn domain_override(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(_: i32) -> Option<KnownProtocols>>
pub fn domain_override( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(_: i32) -> Option<KnownProtocols>>
Returns an iterator which yields the valid enum values contained in domain_override.
Sourcepub fn push_domain_override(&mut self, value: KnownProtocols)
pub fn push_domain_override(&mut self, value: KnownProtocols)
Appends the provided enum value to domain_override.