Module command

Module command 

Modules

routing_service_client
Generated client implementations.

Structs

AddRuleRequest
AddRuleResponse
BalancerMsg
Config
GetBalancerInfoRequest
GetBalancerInfoResponse
OverrideBalancerTargetRequest
OverrideBalancerTargetResponse
OverrideInfo
PrincipleTargetInfo
RemoveRuleRequest
RemoveRuleResponse
RoutingContext
RoutingContext is the context with information relative to routing process. It conforms to the structure of xray.features.routing.Context and xray.features.routing.Route.
SubscribeRoutingStatsRequest
SubscribeRoutingStatsRequest subscribes to routing statistics channel if opened by xray-core.
TestRouteRequest
TestRouteRequest manually tests a routing result according to the routing context message.