pub struct SubscribeRoutingStatsRequest {
pub field_selectors: Vec<String>,
}Expand description
SubscribeRoutingStatsRequest subscribes to routing statistics channel if opened by xray-core.
- FieldSelectors selects a subset of fields in routing statistics to return.
Valid selectors:
- inbound: Selects connection’s inbound tag.
- network: Selects connection’s network.
- ip: Equivalent as “ip_source” and “ip_target”, selects both source and target IP.
- port: Equivalent as “port_source” and “port_target”, selects both source and target port.
- domain: Selects target domain.
- protocol: Select connection’s protocol.
- user: Select connection’s inbound user email.
- attributes: Select connection’s additional attributes.
- outbound: Equivalent as “outbound” and “outbound_group”, select both outbound tag and outbound group tags.
- If FieldSelectors is left empty, all fields will be returned.
Fields
field_selectors: Vec<String>Trait Implementations
Sourceimpl Clone for SubscribeRoutingStatsRequest
impl Clone for SubscribeRoutingStatsRequest
Sourcefn clone(&self) -> SubscribeRoutingStatsRequest
fn clone(&self) -> SubscribeRoutingStatsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubscribeRoutingStatsRequest
impl Debug for SubscribeRoutingStatsRequest
Sourceimpl Message for SubscribeRoutingStatsRequest
impl Message for SubscribeRoutingStatsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for SubscribeRoutingStatsRequest
impl Name for SubscribeRoutingStatsRequest
Sourceconst NAME: &'static str = "SubscribeRoutingStatsRequest"
const NAME: &'static str = "SubscribeRoutingStatsRequest"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "xray.app.router.command"
const PACKAGE: &'static str = "xray.app.router.command"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for SubscribeRoutingStatsRequest
impl PartialEq for SubscribeRoutingStatsRequest
Sourcefn eq(&self, other: &SubscribeRoutingStatsRequest) -> bool
fn eq(&self, other: &SubscribeRoutingStatsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SubscribeRoutingStatsRequest