pub struct RoutingRule {Show 13 fields
pub rule_tag: String,
pub domain: Vec<Domain>,
pub geoip: Vec<GeoIp>,
pub port_list: Option<PortList>,
pub networks: Vec<i32>,
pub source_geoip: Vec<GeoIp>,
pub source_port_list: Option<PortList>,
pub user_email: Vec<String>,
pub inbound_tag: Vec<String>,
pub protocol: Vec<String>,
pub attributes: HashMap<String, String>,
pub domain_matcher: String,
pub target_tag: Option<TargetTag>,
}Fields
rule_tag: Stringdomain: Vec<Domain>List of domains for target domain matching.
geoip: Vec<GeoIp>List of GeoIPs for target IP address matching. If this entry exists, the cidr above will have no effect. GeoIP fields with the same country code are supposed to contain exactly same content. They will be merged during runtime. For customized GeoIPs, please leave country code empty.
port_list: Option<PortList>List of ports.
networks: Vec<i32>List of networks for matching.
source_geoip: Vec<GeoIp>List of GeoIPs for source IP address matching. If this entry exists, the source_cidr above will have no effect.
source_port_list: Option<PortList>List of ports for source port matching.
user_email: Vec<String>inbound_tag: Vec<String>protocol: Vec<String>attributes: HashMap<String, String>domain_matcher: Stringtarget_tag: Option<TargetTag>Implementations