pub struct OutboundStatus {
pub alive: bool,
pub delay: i64,
pub last_error_reason: String,
pub outbound_tag: String,
pub last_seen_time: i64,
pub last_try_time: i64,
pub health_ping: Option<HealthPingMeasurementResult>,
}Fields
alive: bool@Document Whether this outbound is usable @Restriction ReadOnlyForUser
delay: i64@Document The time for probe request to finish. @Type time.ms @Restriction ReadOnlyForUser
last_error_reason: String@Document The last error caused this outbound failed to relay probe request @Restriction NotMachineReadable
outbound_tag: String@Document The outbound tag for this Server @Type id.outboundTag
last_seen_time: i64@Document The time this outbound is known to be alive @Type id.outboundTag
last_try_time: i64@Document The time this outbound is tried @Type id.outboundTag
health_ping: Option<HealthPingMeasurementResult>Trait Implementations
Sourceimpl Clone for OutboundStatus
impl Clone for OutboundStatus
Sourcefn clone(&self) -> OutboundStatus
fn clone(&self) -> OutboundStatus
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutboundStatus
impl Debug for OutboundStatus
Sourceimpl Default for OutboundStatus
impl Default for OutboundStatus
Sourceimpl Message for OutboundStatus
impl Message for OutboundStatus
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for OutboundStatus
impl Name for OutboundStatus
Sourceconst NAME: &'static str = "OutboundStatus"
const NAME: &'static str = "OutboundStatus"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "xray.core.app.observatory"
const PACKAGE: &'static str = "xray.core.app.observatory"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for OutboundStatus
impl PartialEq for OutboundStatus
impl StructuralPartialEq for OutboundStatus