pub struct SocketConfig {Show 20 fields
pub mark: i32,
pub tfo: i32,
pub tproxy: i32,
pub receive_original_dest_address: bool,
pub bind_address: Vec<u8>,
pub bind_port: u32,
pub accept_proxy_protocol: bool,
pub domain_strategy: i32,
pub dialer_proxy: String,
pub tcp_keep_alive_interval: i32,
pub tcp_keep_alive_idle: i32,
pub tcp_congestion: String,
pub interface: String,
pub v6only: bool,
pub tcp_window_clamp: i32,
pub tcp_user_timeout: i32,
pub tcp_max_seg: i32,
pub tcp_no_delay: bool,
pub tcp_mptcp: bool,
pub custom_sockopt: Vec<CustomSockopt>,
}Expand description
SocketConfig is options to be applied on network sockets.
Fields
mark: i32Mark of the connection. If non-zero, the value will be set to SO_MARK.
tfo: i32TFO is the state of TFO settings.
tproxy: i32TProxy is for enabling TProxy socket option.
receive_original_dest_address: boolReceiveOriginalDestAddress is for enabling IP_RECVORIGDSTADDR socket option. This option is for UDP only.
bind_address: Vec<u8>bind_port: u32accept_proxy_protocol: booldomain_strategy: i32dialer_proxy: Stringtcp_keep_alive_interval: i32tcp_keep_alive_idle: i32tcp_congestion: Stringinterface: Stringv6only: booltcp_window_clamp: i32tcp_user_timeout: i32tcp_max_seg: i32tcp_no_delay: booltcp_mptcp: boolcustom_sockopt: Vec<CustomSockopt>Implementations
Sourceimpl SocketConfig
impl SocketConfig
Sourcepub fn tproxy(&self) -> TProxyMode
pub fn tproxy(&self) -> TProxyMode
Returns the enum value of tproxy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tproxy(&mut self, value: TProxyMode)
pub fn set_tproxy(&mut self, value: TProxyMode)
Sets tproxy to the provided enum value.
Sourcepub fn domain_strategy(&self) -> DomainStrategy
pub fn domain_strategy(&self) -> DomainStrategy
Returns the enum value of domain_strategy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_domain_strategy(&mut self, value: DomainStrategy)
pub fn set_domain_strategy(&mut self, value: DomainStrategy)
Sets domain_strategy to the provided enum value.