pub struct RoutingRule {Show 17 fields
pub rule_tag: String,
pub domain: Vec<Domain>,
pub cidr: Vec<Cidr>,
pub geoip: Vec<GeoIp>,
pub port_range: Option<PortRange>,
pub port_list: Option<PortList>,
pub network_list: Option<NetworkList>,
pub networks: Vec<i32>,
pub source_cidr: Vec<Cidr>,
pub source_geoip: Vec<GeoIp>,
pub source_port_list: Option<PortList>,
pub user_email: Vec<String>,
pub inbound_tag: Vec<String>,
pub protocol: Vec<String>,
pub attributes: HashMap<String, String>,
pub domain_matcher: String,
pub target_tag: Option<TargetTag>,
}Fields
rule_tag: Stringdomain: Vec<Domain>List of domains for target domain matching.
cidr: Vec<Cidr>List of CIDRs for target IP address matching. Deprecated. Use geoip below.
geoip: Vec<GeoIp>List of GeoIPs for target IP address matching. If this entry exists, the cidr above will have no effect. GeoIP fields with the same country code are supposed to contain exactly same content. They will be merged during runtime. For customized GeoIPs, please leave country code empty.
port_range: Option<PortRange>A range of port [from, to]. If the destination port is in this range, this rule takes effect. Deprecated. Use port_list.
port_list: Option<PortList>List of ports.
network_list: Option<NetworkList>List of networks. Deprecated. Use networks.
networks: Vec<i32>List of networks for matching.
source_cidr: Vec<Cidr>List of CIDRs for source IP address matching.
source_geoip: Vec<GeoIp>List of GeoIPs for source IP address matching. If this entry exists, the source_cidr above will have no effect.
source_port_list: Option<PortList>List of ports for source port matching.
user_email: Vec<String>inbound_tag: Vec<String>protocol: Vec<String>attributes: HashMap<String, String>domain_matcher: Stringtarget_tag: Option<TargetTag>Implementations