pub struct StreamConfig {
pub protocol: i32,
pub protocol_name: String,
pub transport_settings: Vec<TransportConfig>,
pub security_type: String,
pub security_settings: Vec<TypedMessage>,
pub socket_settings: Option<SocketConfig>,
}Fields
protocol: i32👎Deprecated
Effective network. Deprecated. Use the string form below.
protocol_name: StringEffective network.
transport_settings: Vec<TransportConfig>security_type: StringType of security. Must be a message name of the settings proto.
security_settings: Vec<TypedMessage>Settings for transport security. For now the only choice is TLS.
socket_settings: Option<SocketConfig>Implementations
Sourceimpl StreamConfig
impl StreamConfig
Sourcepub fn protocol(&self) -> TransportProtocol
pub fn protocol(&self) -> TransportProtocol
Returns the enum value of protocol, or the default if the field is set to an invalid enum value.
Sourcepub fn set_protocol(&mut self, value: TransportProtocol)
pub fn set_protocol(&mut self, value: TransportProtocol)
Sets protocol to the provided enum value.